==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebDockManagerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerLayoutDescriptionMetadata } from "./WebDockManagerLayoutDescriptionMetadata";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebDockManagerResourceStringsDescriptionMetadata } from "./WebDockManagerResourceStringsDescriptionMetadata";
import { WebDockManagerDescription } from "./WebDockManagerDescription";
/**
 * @hidden
 */
var WebDockManagerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockManagerDescriptionMetadata, _super);
    function WebDockManagerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerDescriptionMetadata.b = function (a) {
        if (WebDockManagerDescriptionMetadata.a == null) {
            WebDockManagerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerDescriptionMetadata.c(WebDockManagerDescriptionMetadata.a);
        }
        if (a.g(WebDockManagerDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDockManagerDescriptionMetadata.a);
        WebDockManagerLayoutDescriptionMetadata.d(a);
        WebDockManagerPaneDescriptionMetadata.d(a);
        WebDockManagerPointDescriptionMetadata.d(a);
        WebContentPaneDescriptionMetadata.d(a);
        WebDockManagerResourceStringsDescriptionMetadata.d(a);
    };
    WebDockManagerDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManager");
        a.item("Layout", "ExportedType:WebDockManagerLayout");
        a.item("DraggedPane", "ExportedType:WebDockManagerPane");
        a.item("DropPosition", "ExportedType:WebDockManagerPoint");
        a.item("ActivePane", "ExportedType:WebContentPane");
        a.item("AllowMaximize", "Boolean");
        a.item("MaximizedPane", "ExportedType:WebDockManagerPane");
        a.item("ResourceStrings", "ExportedType:WebDockManagerResourceStrings");
        a.item("AllowFloatingPanesResize", "Boolean");
        a.item("DisableKeyboardNavigation", "Boolean");
    };
    WebDockManagerDescriptionMetadata.d = function (a) {
        WebDockManagerDescriptionMetadata.b(a);
        a.u("WebDockManager", function () { return new WebDockManagerDescription(); });
        a.t("WebDockManager", WebDockManagerDescriptionMetadata.a);
    };
    WebDockManagerDescriptionMetadata.$t = markType(WebDockManagerDescriptionMetadata, 'WebDockManagerDescriptionMetadata');
    WebDockManagerDescriptionMetadata.a = null;
    return WebDockManagerDescriptionMetadata;
}(Base));
export { WebDockManagerDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebDockManagerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerLayoutDescriptionMetadata } from "./WebDockManagerLayoutDescriptionMetadata";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebDockManagerResourceStringsDescriptionMetadata } from "./WebDockManagerResourceStringsDescriptionMetadata";
import { WebDockManagerDescription } from "./WebDockManagerDescription";
/**
 * @hidden
 */
var WebDockManagerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockManagerDescriptionMetadata, _super);
    function WebDockManagerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerDescriptionMetadata.b = function (a) {
        if (WebDockManagerDescriptionMetadata.a == null) {
            WebDockManagerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerDescriptionMetadata.c(WebDockManagerDescriptionMetadata.a);
        }
        if (a.j(WebDockManagerDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDockManagerDescriptionMetadata.a);
        WebDockManagerLayoutDescriptionMetadata.d(a);
        WebDockManagerPaneDescriptionMetadata.d(a);
        WebDockManagerPointDescriptionMetadata.d(a);
        WebContentPaneDescriptionMetadata.d(a);
        WebDockManagerResourceStringsDescriptionMetadata.d(a);
    };
    WebDockManagerDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManager");
        a.item("__tagNameWC", "String:igc-dockmanager");
        a.item("Layout", "ExportedType:WebDockManagerLayout");
        a.item("DraggedPane", "ExportedType:WebDockManagerPane");
        a.item("DropPosition", "ExportedType:WebDockManagerPoint");
        a.item("ActivePane", "ExportedType:WebContentPane");
        a.item("AllowMaximize", "Boolean");
        a.item("MaximizedPane", "ExportedType:WebDockManagerPane");
        a.item("ResourceStrings", "ExportedType:WebDockManagerResourceStrings");
        a.item("AllowFloatingPanesResize", "Boolean");
        a.item("DisableKeyboardNavigation", "Boolean");
    };
    WebDockManagerDescriptionMetadata.d = function (a) {
        WebDockManagerDescriptionMetadata.b(a);
        a.aa("WebDockManager", function () { return new WebDockManagerDescription(); });
        a.z("WebDockManager", WebDockManagerDescriptionMetadata.a);
    };
    WebDockManagerDescriptionMetadata.$t = markType(WebDockManagerDescriptionMetadata, 'WebDockManagerDescriptionMetadata');
    WebDockManagerDescriptionMetadata.a = null;
    return WebDockManagerDescriptionMetadata;
}(Base));
export { WebDockManagerDescriptionMetadata };
